@@ -22,7 +22,7 @@ def fmt(prog):
     return CustomHelpFormatter(prog)
 
 
-def cli():
+def cli() -> argparse.Namespace:
     # noinspection PyTypeChecker
     parser = argparse.ArgumentParser(prog='pymirror', formatter_class=fmt,
                                      add_help=False)
@@ -64,6 +64,7 @@ def cli():
         action='store_false',
         default=False)
     parser.add_argument(
+        '-D',
         '--debug',
         help='Debug',
         action='store_true',
@@ -85,6 +86,5 @@ def cli():
                         action='version',
                         version=f'%(prog)s {__version__}')
 
-
     args = parser.parse_args()
     return args
